import { MapPin, Phone, Mail } from 'lucide-react';

export default function Footer() {
  return (
    <footer className="bg-blue-900 text-white py-12" aria-label="Site footer">
      <div className="container mx-auto px-4">
        <div className="grid md:grid-cols-3 gap-8">
          <div>
            <h3 className="text-xl font-bold mb-4">Drain Busters</h3>
            <p className="text-gray-300">Your trusted plumbing experts serving the Greater Rochester area.</p>
            <address className="text-gray-300 mt-4 not-italic">
              <MapPin className="inline-block h-5 w-5 mr-2" aria-hidden="true" />
              471 Peck Rd, Spencerport, NY 14559
            </address>
          </div>
          <nav className="footer-nav" aria-label="Footer navigation">
            <h3 className="text-xl font-bold mb-4">Quick Links</h3>
            <ul className="space-y-2">
              <li>
                <a 
                  href="#services" 
                  className="text-gray-300 hover:text-white transition-colors"
                  aria-label="View our services"
                >
                  Services
                </a>
              </li>
              <li>
                <a 
                  href="#about" 
                  className="text-gray-300 hover:text-white transition-colors"
                  aria-label="Learn about us"
                >
                  About Us
                </a>
              </li>
              <li>
                <a 
                  href="#contact" 
                  className="text-gray-300 hover:text-white transition-colors"
                  aria-label="Contact us"
                >
                  Contact
                </a>
              </li>
            </ul>
          </nav>
          <div>
            <h3 className="text-xl font-bold mb-4">Emergency Service</h3>
            <p className="text-gray-300">Available 24/7 for all your plumbing emergencies.</p>
            <div className="mt-4 space-y-2">
              <a 
                href="tel:(585)-222-2564" 
                className="text-white font-bold block hover:text-blue-200 transition-colors"
                aria-label="Call us at (585) 222-CLOG"
              >
                <Phone className="inline-block h-5 w-5 mr-2" aria-hidden="true" />
                (585) 222-CLOG
              </a>
              <span className="text-gray-300 block ml-7">(585) 222-2564</span>
              <a 
                href="mailto:Help@DrainBustersNY.com" 
                className="text-white font-bold block hover:text-blue-200 transition-colors"
                aria-label="Email us at Help@DrainBustersNY.com"
              >
                <Mail className="inline-block h-5 w-5 mr-2" aria-hidden="true" />
                Help@DrainBustersNY.com
              </a>
            </div>
          </div>
        </div>
        <div className="border-t border-blue-800 mt-8 pt-8 text-center">
          <p className="text-gray-300">
            &copy; {new Date().getFullYear()} Drain Busters. All rights reserved.
          </p>
        </div>
      </div>

      {/* Structured Data for Local Business */}
      <script type="application/ld+json" dangerouslySetInnerHTML={{
        __html: JSON.stringify({
          "@context": "https://schema.org",
          "@type": "Plumber",
          "name": "Drain Busters",
          "image": "https://www.drainbustersny.com/DB%20Full%20Logo%20White%20Text%20Small.png",
          "description": "Professional plumbing services in Rochester, NY. Available 24/7 for emergency service.",
          "address": {
            "@type": "PostalAddress",
            "streetAddress": "471 Peck Rd",
            "addressLocality": "Spencerport",
            "addressRegion": "NY",
            "postalCode": "14559",
            "addressCountry": "US"
          },
          "geo": {
            "@type": "GeoCoordinates",
            "latitude": 43.239202,
            "longitude": -77.777073
          },
          "url": "https://www.drainbustersny.com",
          "telephone": "+15852222564",
          "openingHoursSpecification": {
            "@type": "OpeningHoursSpecification",
            "dayOfWeek": [
              "Monday", "Tuesday", "Wednesday", "Thursday",
              "Friday", "Saturday", "Sunday"
            ],
            "opens": "00:00",
            "closes": "23:59"
          }
        })
      }} />
    </footer>
  );
}